@@ -2,7 +2,7 @@
 
 _plugins = [
     "V1",
-    # "V2",
+    "V2",
     # "V3",
 ]
 
